@@ -1,7 +1,7 @@
 package Guacamole;
 our $AUTHORITY = 'cpan:XSAWYERX';
 # ABSTRACT: A parser toolkit for Standard Perl
-$Guacamole::VERSION = '0.005';
+$Guacamole::VERSION = '0.006';
 use strict;
 use warnings;
 use Marpa::R2;
@@ -1378,12 +1378,58 @@ VersionNumberSegment ~ [0-9] [0-9] [0-9]
                      | [0-9]
 
 LitNumber ::= LitNumberDec
-LitNumberDec ~ Digits Period Digits
-             | Digits Period
-             | Period Digits
-             | Digits
+            | LitNumberOct
+            | LitNumberHex
+            | LitNumberBin
+
+LitNumberDec ::= NumberDec
+LitNumberOct ::= NumberOct
+LitNumberHex ::= NumberHex
+LitNumberBin ::= NumberBin
+
+NumberDec ~ NumberDecInt
+          | NumberDecInt ExpDec
+          | NumberDecInt '.' DigitsDec
+          | NumberDecInt '.' DigitsDec ExpDec
+          | '.' DigitDec DigitsDec
+          | '.' DigitDec DigitsDec ExpDec
+
+NumberDecInt ~ [1-9] DigitsDec
+             | '0'
+
+NumberOct ~ '0' Underbars DigitOct DigitsOct
+          | '0' Underbars DigitOct DigitsOct ExpHex
+          | '0' DigitsOct '.' DigitOct DigitsOct ExpHex
+
+NumberHex ~ '0' [xX] Underbars DigitHex DigitsHex
+          | '0' [xX] Underbars DigitHex DigitsHex ExpHex
+          | '0' [xX] DigitsHex '.' DigitHex DigitsHex ExpHex
+
+NumberBin ~ '0' [bB] Underbars DigitBin DigitsBin
+          | '0' [bB] Underbars DigitBin DigitsBin ExpHex
+          | '0' [bB] DigitsBin '.' DigitBin DigitsBin ExpHex
+
+ExpDec ~ [eE] [+-] ExpDecExp
+       | [eE] [_] [+-] ExpDecExp
+       | [eE] ExpDecExp
+
+ExpDecExp ~ Underbars DigitDec DigitsDec
+Underbars ~ [_]*
+
+ExpHex ~ [pP] [+-] DigitDec DigitsDec
+       | [pP] DigitDec DigitsDec
+
+DigitDec    ~ [0-9]
+DigitsDec   ~ [0-9_]*
+
+DigitOct    ~ [0-7]
+DigitsOct   ~ [0-7_]*
+DigitHex    ~ [0-9a-fA-F]
+DigitsHex   ~ [0-9a-fA-F_]*
+
+DigitBin    ~ [01]
+DigitsBin   ~ [01_]*
 
-Period      ~ '.'
 Digits      ~ [0-9]+
 SingleQuote ~ [']
 DoubleQuote ~ ["]
@@ -2093,7 +2139,7 @@ Guacamole - A parser toolkit for Standard Perl
 
 =head1 VERSION
 
-version 0.005
+version 0.006
 
 =head1 SYNOPSIS
 
